@@ -1,11 +1,10 @@
 use std::env;
 use std::path::{PathBuf, MAIN_SEPARATOR as SLASH};
 
-use lazy_static::lazy_static;
-
 use config::Config;
-use imageproc::{assert_processed_path_matches, ImageMetaResponse, Processor};
-use utils::fs as ufs;
+use imageproc::{assert_processed_path_matches, fix_orientation, ImageMetaResponse, Processor};
+use libs::image::{self, DynamicImage, GenericImageView, Pixel};
+use libs::once_cell::sync::Lazy;
 
 static CONFIG: &str = r#"
 title = "imageproc integration tests"
@@ -17,18 +16,10 @@ build_search_index = false
 highlight_code = false
 "#;
 
-lazy_static! {
-    static ref TEST_IMGS: PathBuf =
-        [env!("CARGO_MANIFEST_DIR"), "tests", "test_imgs"].iter().collect();
-    static ref TMPDIR: PathBuf = {
-        let tmpdir = option_env!("CARGO_TARGET_TMPDIR").map(PathBuf::from).unwrap_or_else(|| {
-            env::current_exe().unwrap().parent().unwrap().parent().unwrap().join("tmpdir")
-        });
-        ufs::ensure_directory_exists(&tmpdir).unwrap();
-        tmpdir
-    };
-    static ref PROCESSED_PREFIX: String = format!("static{0}processed_images{0}", SLASH);
-}
+static TEST_IMGS: Lazy<PathBuf> =
+    Lazy::new(|| [env!("CARGO_MANIFEST_DIR"), "tests", "test_imgs"].iter().collect());
+static PROCESSED_PREFIX: Lazy<String> =
+    Lazy::new(|| format!("static{0}processed_images{0}", SLASH));
 
 #[allow(clippy::too_many_arguments)]
 fn image_op_test(
@@ -44,9 +35,9 @@ fn image_op_test(
     orig_height: u32,
 ) {
     let source_path = TEST_IMGS.join(source_img);
-
+    let tmpdir = tempfile::tempdir().unwrap().into_path();
     let config = Config::parse(CONFIG).unwrap();
-    let mut proc = Processor::new(TMPDIR.clone(), &config);
+    let mut proc = Processor::new(tmpdir.clone(), &config);
 
     let resp =
         proc.enqueue(source_img.into(), source_path, op, width, height, format, None).unwrap();
@@ -60,7 +51,7 @@ fn image_op_test(
     proc.do_process().unwrap();
 
     let processed_path = PathBuf::from(&resp.static_path);
-    let processed_size = imageproc::read_image_metadata(&TMPDIR.join(processed_path))
+    let processed_size = imageproc::read_image_metadata(&tmpdir.join(processed_path))
         .map(|meta| (meta.width, meta.height))
         .unwrap();
     assert_eq!(processed_size, (expect_width, expect_height));
@@ -163,4 +154,75 @@ fn read_image_metadata_webp() {
     );
 }
 
+#[test]
+fn fix_orientation_test() {
+    fn load_img_and_fix_orientation(img_name: &str) -> DynamicImage {
+        let path = TEST_IMGS.join(img_name);
+        let img = image::open(&path).unwrap();
+        fix_orientation(&img, &path).unwrap_or(img)
+    }
+
+    let img = image::open(TEST_IMGS.join("exif_1.jpg")).unwrap();
+    assert!(check_img(img));
+    assert!(check_img(load_img_and_fix_orientation("exif_0.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_1.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_2.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_3.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_4.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_5.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_6.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_7.jpg")));
+    assert!(check_img(load_img_and_fix_orientation("exif_8.jpg")));
+}
+
+#[test]
+fn resize_image_applies_exif_rotation() {
+    // No exif metadata
+    assert!(resize_and_check("exif_0.jpg"));
+    // 1: Horizontal (normal)
+    assert!(resize_and_check("exif_1.jpg"));
+    // 2: Mirror horizontal
+    assert!(resize_and_check("exif_2.jpg"));
+    // 3: Rotate 180
+    assert!(resize_and_check("exif_3.jpg"));
+    // 4: Mirror vertical
+    assert!(resize_and_check("exif_4.jpg"));
+    // 5: Mirror horizontal and rotate 270 CW
+    assert!(resize_and_check("exif_5.jpg"));
+    // 6: Rotate 90 CW
+    assert!(resize_and_check("exif_6.jpg"));
+    // 7: Mirror horizontal and rotate 90 CW
+    assert!(resize_and_check("exif_7.jpg"));
+    // 8: Rotate 270 CW
+    assert!(resize_and_check("exif_8.jpg"));
+}
+
+fn resize_and_check(source_img: &str) -> bool {
+    let source_path = TEST_IMGS.join(source_img);
+    let tmpdir = tempfile::tempdir().unwrap().into_path();
+    let config = Config::parse(CONFIG).unwrap();
+    let mut proc = Processor::new(tmpdir.clone(), &config);
+
+    let resp = proc
+        .enqueue(source_img.into(), source_path, "scale", Some(16), Some(16), "jpg", None)
+        .unwrap();
+
+    proc.do_process().unwrap();
+    let processed_path = PathBuf::from(&resp.static_path);
+    let img = image::open(&tmpdir.join(processed_path)).unwrap();
+    check_img(img)
+}
+
+// Checks that an image has the correct orientation
+fn check_img(img: DynamicImage) -> bool {
+    // top left is red
+    img.get_pixel(0, 0)[0] > 250 // because of the jpeg compression some colors are a bit less than 255
+    // top right is green
+        && img.get_pixel(15, 0)[1] > 250
+    // bottom left is blue
+        && img.get_pixel(0, 15)[2] > 250
+    // bottom right is white
+        && img.get_pixel(15, 15).channels() == [255, 255, 255, 255]
+}
+
 // TODO: Test that hash remains the same if physical path is changed
