@@ -1,9 +1,9 @@
+pub mod anchors;
 pub mod de;
 pub mod fs;
-pub mod links;
-pub mod minify;
 pub mod net;
 pub mod site;
 pub mod slugs;
+pub mod table_of_contents;
 pub mod templates;
-pub mod vec;
+pub mod types;
